@@ -1,17 +1,13 @@
 timeSliceVAR <- function(data, p = 1, penalty = "ENET", opt) {
-
   if (penalty == "ENET") {
     # call timeslice with ENET
     out <- timeSliceVAR_ENET(data, p, opt)
-
   } else if (penalty == "SCAD" | penalty == "MCP" | penalty == "SCAD2") {
     # call timeslice with SCAD or MCP
     out <- timeSliceVAR_SCAD(data, p, opt, penalty)
-
   } else {
     # error
     stop("Unknown penalty. Possible values are \"ENET\", \"SCAD\" or \"MCP\".")
-
   }
 
   out$penalty <- penalty
@@ -19,7 +15,6 @@ timeSliceVAR <- function(data, p = 1, penalty = "ENET", opt) {
 }
 
 timeSliceVAR_ENET <- function(data, p, opt) {
-
   t <- Sys.time()
   nr <- nrow(data)
   nc <- ncol(data)
@@ -27,7 +22,7 @@ timeSliceVAR_ENET <- function(data, p, opt) {
   threshold <- ifelse(!is.null(opt$threshold), opt$threshold, FALSE)
   returnFit <- ifelse(!is.null(opt$returnFit), opt$returnFit, FALSE)
   methodCov <- ifelse(!is.null(opt$methodCov), opt$methodCov, "tiger")
-  a  <- ifelse(!is.null(opt$alpha), opt$alpha, 1)
+  a <- ifelse(!is.null(opt$alpha), opt$alpha, 1)
   l <- ifelse(!is.null(opt$leaveOut), opt$leaveOut, 10)
   ## TODO: Add the look ahead period > 1
   winLength <- nr - l
@@ -36,27 +31,27 @@ timeSliceVAR_ENET <- function(data, p, opt) {
   trDt <- transformData(data[1:winLength, ], p, opt)
   lam <- glmnet::glmnet(trDt$X, trDt$y, alpha = a)$lambda
 
-  resTS <- matrix(0, ncol = l+1, nrow = length(lam))
-  resTS[ , 1] <- lam
+  resTS <- matrix(0, ncol = l + 1, nrow = length(lam))
+  resTS[, 1] <- lam
 
   for (i in 1:l) {
-      d <- data[i:(winLength + i), ]
-      fit <- varENET(d[1:(nrow(d)-1), ], p, lam, opt)
-      resTS[, i+1] <- computeErrors(d, p, fit)
+    d <- data[i:(winLength + i), ]
+    fit <- varENET(d[1:(nrow(d) - 1), ], p, lam, opt)
+    resTS[, i + 1] <- computeErrors(d, p, fit)
   }
 
   finalRes <- matrix(0, ncol = 3, nrow = length(lam))
-  finalRes[,1] <- lam
-  finalRes[,2] <- rowMeans(resTS[,2:(l+1)])
+  finalRes[, 1] <- lam
+  finalRes[, 2] <- rowMeans(resTS[, 2:(l + 1)])
   for (k in 1:length(lam)) {
-    finalRes[k,3] <- stats::sd(resTS[k,2:(l+1)])
+    finalRes[k, 3] <- stats::sd(resTS[k, 2:(l + 1)])
   }
 
-  ix <- which(finalRes[,2] == min(finalRes[,2]))[1]
+  ix <- which(finalRes[, 2] == min(finalRes[, 2]))[1]
   fit <- varENET(data, p, finalRes[ix, 1], opt)
 
   Avector <- stats::coef(fit, s = finalRes[ix, 1])
-  A <- matrix(Avector[2:length(Avector)], nrow = nc, ncol = nc*p, byrow = TRUE)
+  A <- matrix(Avector[2:length(Avector)], nrow = nc, ncol = nc * p, byrow = TRUE)
 
   elapsed <- Sys.time() - t
 
@@ -65,7 +60,7 @@ timeSliceVAR_ENET <- function(data, p, opt) {
   if (threshold == TRUE) {
     A <- applyThreshold(A, nr, nc, p)
   }
-  
+
   # Get back the list of VAR matrices (of length p)
   A <- splitMatrix(A, p)
 
@@ -73,7 +68,7 @@ timeSliceVAR_ENET <- function(data, p, opt) {
   res <- computeResiduals(trDt$series, A)
 
   # Create the output
-  output = list()
+  output <- list()
   output$mu <- trDt$mu
   output$A <- A
 
@@ -88,10 +83,10 @@ timeSliceVAR_ENET <- function(data, p, opt) {
   output$time <- elapsed
   output$series <- trDt$series
   output$residuals <- res
-  
+
   # Variance/Covariance estimation
   output$sigma <- estimateCovariance(res)
-  
+
   output$penalty <- "ENET"
   output$method <- "timeSlice"
   attr(output, "class") <- "var"
@@ -103,7 +98,6 @@ timeSliceVAR_ENET <- function(data, p, opt) {
 }
 
 timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
-
   t <- Sys.time()
   nr <- nrow(data)
   nc <- ncol(data)
@@ -111,22 +105,26 @@ timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
   picasso <- ifelse(!is.null(opt$picasso), opt$picasso, FALSE)
   threshold <- ifelse(!is.null(opt$threshold), opt$threshold, FALSE)
   returnFit <- ifelse(!is.null(opt$returnFit), opt$returnFit, FALSE)
-  methodCov <- ifelse(!is.null(opt$methodCov), opt$methodCov, "tiger")  
-  a  <- ifelse(!is.null(opt$alpha), opt$alpha, 1)
+  methodCov <- ifelse(!is.null(opt$methodCov), opt$methodCov, "tiger")
+  a <- ifelse(!is.null(opt$alpha), opt$alpha, 1)
   ## TODO: Add the look ahead period > 1
   l <- ifelse(!is.null(opt$leaveOut), opt$leaveOut, 10)
   winLength <- nr - l
   horizon <- 1
-  
+
   trDt <- transformData(data[1:winLength, ], p, opt)
 
   if (!picasso) {
     if (penalty == "SCAD") {
-      lam <- ncvreg::ncvreg(as.matrix(trDt$X), trDt$y, family = "gaussian", penalty = "SCAD",
-                            alpha = 1)$lambda
+      lam <- ncvreg::ncvreg(as.matrix(trDt$X), trDt$y,
+        family = "gaussian", penalty = "SCAD",
+        alpha = 1
+      )$lambda
     } else if (penalty == "MCP") {
-      lam <- ncvreg::ncvreg(as.matrix(trDt$X), trDt$y, family = "gaussian", penalty = "MCP",
-                            alpha = 1)$lambda
+      lam <- ncvreg::ncvreg(as.matrix(trDt$X), trDt$y,
+        family = "gaussian", penalty = "MCP",
+        alpha = 1
+      )$lambda
     } else {
       stop("[WIP] Only SCAD and MCP regression are supported.")
       # lam <- sparsevar::scadReg(as(trDt$X, "dgCMatrix"), trDt$y, alpha = 1)$lambda
@@ -135,53 +133,52 @@ timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
     lam <- picasso::picasso(trDt$X, trDt$y, method = "scad", nlambda = 100)$lambda
   }
 
-  resTS <- matrix(0, ncol = l+1, nrow = length(lam))
-  resTS[ , 1] <- lam
+  resTS <- matrix(0, ncol = l + 1, nrow = length(lam))
+  resTS[, 1] <- lam
 
   for (i in 1:l) {
-
     d <- data[i:(winLength + i), ]
     if (!picasso) {
       if (penalty == "SCAD" | penalty == "SCAD2") {
-        fit <- varSCAD(d[1:(nrow(d)-1), ], p, lam, opt, penalty)
-        resTS[, i+1] <- computeErrors(d, p, fit, penalty = penalty)
+        fit <- varSCAD(d[1:(nrow(d) - 1), ], p, lam, opt, penalty)
+        resTS[, i + 1] <- computeErrors(d, p, fit, penalty = penalty)
       } else {
-        fit <- varMCP(d[1:(nrow(d)-1), ], p, lam, opt)
-        resTS[, i+1] <- computeErrors(d, p, fit, penalty = "MCP")
+        fit <- varMCP(d[1:(nrow(d) - 1), ], p, lam, opt)
+        resTS[, i + 1] <- computeErrors(d, p, fit, penalty = "MCP")
       }
     } else {
       trDt <- transformData(d, p, opt)
       fit <- picasso::picasso(trDt$X, trDt$y, method = "scad", lambda = lam)
-      resTS[, i+1] <- computeErrorsPicasso(d, p, fit)
+      resTS[, i + 1] <- computeErrorsPicasso(d, p, fit)
     }
   }
 
   finalRes <- matrix(0, ncol = 3, nrow = length(lam))
-  finalRes[,1] <- lam
-  finalRes[,2] <- rowMeans(resTS[,2:(l+1)])
+  finalRes[, 1] <- lam
+  finalRes[, 2] <- rowMeans(resTS[, 2:(l + 1)])
   for (k in 1:length(lam)) {
-    finalRes[k,3] <- stats::sd(resTS[k,2:(l+1)])
+    finalRes[k, 3] <- stats::sd(resTS[k, 2:(l + 1)])
   }
 
-  ix <- which(finalRes[,2] == min(finalRes[,2]))[1]
+  ix <- which(finalRes[, 2] == min(finalRes[, 2]))[1]
 
   if (!picasso) {
     if (penalty == "SCAD") {
-      fit <- varSCAD(data, p, finalRes[ix,1], opt)
+      fit <- varSCAD(data, p, finalRes[ix, 1], opt)
       Avector <- fit$beta[2:nrow(fit$beta), 1]
     } else if (penalty == "MCP") {
-      fit <- varMCP(data, p, finalRes[ix,1], opt)
+      fit <- varMCP(data, p, finalRes[ix, 1], opt)
       Avector <- fit$beta[2:nrow(fit$beta), 1]
     } else {
-      fit <- varSCAD(data, p, finalRes[ix,1], opt, penalty == "SCAD2")
+      fit <- varSCAD(data, p, finalRes[ix, 1], opt, penalty == "SCAD2")
       Avector <- fit$beta[1:nrow(fit$beta), 1]
     }
-    A <- matrix(Avector, nrow = nc, ncol = nc*p, byrow = TRUE)
+    A <- matrix(Avector, nrow = nc, ncol = nc * p, byrow = TRUE)
   } else {
     trDt <- transformData(data, p, opt)
-    fit <- picasso::picasso(trDt$X, trDt$y, method = "scad", lambda = finalRes[ix,1])
+    fit <- picasso::picasso(trDt$X, trDt$y, method = "scad", lambda = finalRes[ix, 1])
     Avector <- fit$beta[, 1]
-    A <- matrix(Avector, nrow = nc, ncol = nc*p, byrow = TRUE)
+    A <- matrix(Avector, nrow = nc, ncol = nc * p, byrow = TRUE)
   }
 
   elapsed <- Sys.time() - t
@@ -190,7 +187,7 @@ timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
   # the threshold
   if (!is.null(opt$threshold)) {
     if (opt$threshold == TRUE) {
-      tr <- 1 / sqrt(p*nc*log(nr))
+      tr <- 1 / sqrt(p * nc * log(nr))
       L <- abs(A) >= tr
       A <- A * L
     }
@@ -203,7 +200,7 @@ timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
   res <- computeResiduals(data, A)
 
   # Create the output
-  output = list()
+  output <- list()
   output$mu <- trDt$mu
   output$A <- A
 
@@ -220,10 +217,10 @@ timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
   output$time <- elapsed
   output$series <- trDt$series
   output$residuals <- res
-  
+
   # Variance/Covariance estimation
   output$sigma <- estimateCovariance(res)
-  
+
   output$penalty <- penalty
   output$method <- "timeSlice"
   attr(output, "class") <- "var"
@@ -234,7 +231,6 @@ timeSliceVAR_SCAD <- function(data, p, opt, penalty) {
 }
 
 computeErrors <- function(data, p, fit, penalty = "ENET") {
-
   nr <- nrow(data)
   nc <- ncol(data)
   l <- length(fit$lambda)
@@ -242,16 +238,15 @@ computeErrors <- function(data, p, fit, penalty = "ENET") {
   err <- rep(0, ncol = 1, nrow = nr)
 
   for (i in 1:l) {
-
     if (penalty == "ENET") {
       Avector <- stats::coef(fit, s = fit$lambda[i])
-      A <- matrix(Avector[2:length(Avector)], nrow = nc, ncol = nc*p, byrow = TRUE)
+      A <- matrix(Avector[2:length(Avector)], nrow = nc, ncol = nc * p, byrow = TRUE)
     } else if (penalty == "SCAD" | penalty == "MCP") {
       Avector <- fit$beta[2:nrow(fit$beta), i]
-      A <- matrix(Avector, nrow = nc, ncol = nc*p, byrow = TRUE)
+      A <- matrix(Avector, nrow = nc, ncol = nc * p, byrow = TRUE)
     } else {
       Avector <- fit$beta[1:nrow(fit$beta), i]
-      A <- matrix(Avector, nrow = nc, ncol = nc*p, byrow = TRUE)
+      A <- matrix(Avector, nrow = nc, ncol = nc * p, byrow = TRUE)
     }
 
     A <- splitMatrix(A, p)
@@ -259,22 +254,18 @@ computeErrors <- function(data, p, fit, penalty = "ENET") {
     n <- data[nr, ]
 
     f <- rep(0, nrow = nc, ncol = 1)
-    tmpData <- data[((nr-1)- p + 1):(nr - 1), ]
+    tmpData <- data[((nr - 1) - p + 1):(nr - 1), ]
     for (k in 1:p) {
-
-      f <- f + A[[k]] %*% data[((nr-1) - (k-1)), ]
-
+      f <- f + A[[k]] %*% data[((nr - 1) - (k - 1)), ]
     }
 
     err[i] <- mean((f - n)^2)
-
   }
 
   return(err)
 }
 
 computeErrorsPicasso <- function(data, p, fit) {
-
   nr <- nrow(data)
   nc <- ncol(data)
   l <- length(fit$lambda)
@@ -282,24 +273,20 @@ computeErrorsPicasso <- function(data, p, fit) {
   err <- rep(0, ncol = 1, nrow = nr)
 
   for (i in 1:l) {
-
     Avector <- fit$beta[, i]
-    A <- matrix(Avector, nrow = nc, ncol = nc*p, byrow = TRUE)
+    A <- matrix(Avector, nrow = nc, ncol = nc * p, byrow = TRUE)
 
     A <- splitMatrix(A, p)
 
     n <- data[nr, ]
 
     f <- rep(0, nrow = nc, ncol = 1)
-    tmpData <- data[((nr-1)- p + 1):(nr - 1), ]
+    tmpData <- data[((nr - 1) - p + 1):(nr - 1), ]
     for (k in 1:p) {
-
-      f <- f + A[[k]] %*% data[((nr-1) - (k-1)), ]
-
+      f <- f + A[[k]] %*% data[((nr - 1) - (k - 1)), ]
     }
 
     err[i] <- mean((f - n)^2)
-
   }
 
   return(err)
