@@ -15,6 +15,13 @@ test_that("sparsevar", {
   expect_output(str(fit), "List of 11")
   expect_output(cat(attr(fit, "class")), "var")
   expect_output(cat(attr(fit, "type")), "fit")
+  
+  sim <- sparsevar::simulateVAR(N = 30, p = 1)
+  fit <- sparsevar::fitVAR(sim$series, p = 1, 
+                           lambdas_list = c(0.1, 0.5, 0.3))
+  expect_output(str(fit), "List of 11")
+  expect_output(cat(attr(fit, "class")), "var")
+  expect_output(cat(attr(fit, "type")), "fit")
 })
 
 context("Testing IRF and error bands")
